<?php
/**
 * Get a value for parameter in the GET array.
 * @param string $paramName Name of the parameter.
 * @return string|null Value, or null if not found.
 */
function getParamFromGet(string $paramName) {
    $returnValue = null;
    if (isset($_GET[$paramName])) {
        $returnValue = $_GET[$paramName];
        if ($returnValue == '') {
            $returnValue = null;
        }
    }
    return $returnValue;
}

/**
 * Check the state.
 * @param mixed $state State from user.
 * @return string Error message, MT if OK.
 */
function checkState($state) {
    $errorMessage = '';
    $state = strtoupper(trim($state));
    // Is the state known?
    if ($state != 'MI' && $state != 'IL') {
        $errorMessage = "Sorry, '$state' is not a recognized state.<br>";
    }
    // Return results.
    return $errorMessage;
}

/**
 * Check a price.
 * @param mixed $price The price to check.
 * @return string Error message, MT if none.
 */
function checkPrice($price) {
    $priceErrorMessage = '';
    // Check that price is numeric.
    if (!is_numeric($price)) {
        $priceErrorMessage = 'Sorry, price must be a number.<br>';
    }
    // Range check.
    if ($priceErrorMessage == '') {
        if ($price < 0) {
            $priceErrorMessage = 'Sorry, price must be zero or more.<br>';
        }
        if ($price >= 1000000) {
            $priceErrorMessage = 'Sorry, price is too high to be real.<br>';
        }
    }
    return $priceErrorMessage;
}

/**
 * Check a discount rate.
 * @param mixed $discountRate The discount rate to check.
 * @return string Error message, MT if none.
 */
function checkDiscountRate($discountRate) {
    $errorMessage = '';
    // Check that discount rate is numeric.
    if (!is_numeric($discountRate)) {
        $errorMessage = 'Sorry, discount rate must be a number.<br>';
    }
    // Range check.
    if ($errorMessage == '') {
        if ($discountRate < 0) {
            $errorMessage = 'Sorry, discount rate must be zero or more.<br>';
        }
        if ($discountRate >= 0.99) {
            $errorMessage = 'Sorry, discount rate is too high to be real.<br>';
        }
    }
    return $errorMessage;
}
